@@ -86,7 +86,7 @@ sub new_nocaptcha ( $self, %args ) {
 }
 
 sub resolve ( $self, $captcha, $cb = undef ) {
-    weaken $captcha;
+    weaken $captcha if defined wantarray;
 
     my $cv = defined wantarray ? P->cv : undef;
 
@@ -346,7 +346,7 @@ sub _run_resolver_thread ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 88                   | Subroutines::ProhibitExcessComplexity - Subroutine "resolve" with high complexity score (21)                   |
+## |    3 | 88                   | Subroutines::ProhibitExcessComplexity - Subroutine "resolve" with high complexity score (22)                   |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 297, 300             | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
